==> github-widget2-1.0.0.tgz: package/lib/test/PrTable.test.js <==
'use strict';

var _jsxFileName = '../../src/test/PrTable.test.jsx';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _PrTable = require('../components/PrTable/PrTable');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        pullRequests: {
          prsById: {
            246869449: {
              submittedBy: [],
              created: '2017-07-31T20:17:36Z',
              title: 'disregard #2'
            }
          }
        },
        loadingPrTable: false,
        currentPage: { userName: undefined },
        prsByRepo: undefined
      }
    }
  }
};

describe('PrTable component', function () {
  it('should render a component with props as specified ', function () {
    var retrievePrs = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_PrTable.PrTable, {
      loadingPrTable: false,
      retrievePrs: retrievePrs,
      userName: state.widgets.byId.github.currentPage.userName,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 31
      },
      __self: undefined
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      loadingPrTable: false,
      userName: undefined,
      orgName: undefined,
      prsById: {
        246869449: {
          submittedBy: [],
          created: '2017-07-31T20:17:36Z',
          title: 'disregard #2'
        }
      },
      prsByRepo: undefined
    };
    expect((0, _PrTable.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _PrTable.mapDispatchToProps)(dispatch)).toHaveProperty('retrievePrs');
  });
});

==> github-widget2-1.0.4.tgz: package/lib/test/PrTable.test.js <==
'use strict';

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _enzymeToJson = require('enzyme-to-json');

var _enzymeToJson2 = _interopRequireDefault(_enzymeToJson);

var _enzyme = require('enzyme');

var _PrTable = require('../components/PrTable/PrTable');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var state = {
  widgets: {
    byId: {
      github: {
        pullRequests: {
          prsById: {
            246869449: {
              submittedBy: [],
              created: '2017-07-31T20:17:36Z',
              title: 'disregard #2'
            }
          }
        },
        loadingPrTable: false,
        currentPage: { userName: undefined },
        prsByRepo: undefined
      }
    }
  }
};

describe('PrTable component', function () {
  it('should render a component with props as specified ', function () {
    var retrievePrs = jest.fn();
    var component = (0, _enzyme.shallow)(_react2.default.createElement(_PrTable.PrTable, {
      loadingPrTable: false,
      retrievePrs: retrievePrs,
      userName: state.widgets.byId.github.currentPage.userName
    }));
    expect((0, _enzymeToJson2.default)(component)).toMatchSnapshot();
  });

  it("map's given State To Props ", function () {
    var expected = {
      loadingPrTable: false,
      userName: undefined,
      orgName: undefined,
      prsById: {
        246869449: {
          submittedBy: [],
          created: '2017-07-31T20:17:36Z',
          title: 'disregard #2'
        }
      },
      prsByRepo: undefined
    };
    expect((0, _PrTable.mapStateToProps)(state, { widgetId: 'github' })).toEqual(expected);
  });

  it('maps component dispatches to props', function () {
    var dispatch = jest.fn();
    expect((0, _PrTable.mapDispatchToProps)(dispatch)).toHaveProperty('retrievePrs');
  });
});
